/*
 * types.h
 *
 * Copyright 2002, Minoru Murashima. All rights reserved.
 * Distributed under the terms of the BSD License.
 *
 * 
 */


#ifndef types_h
#define types_h


#include<sys/types.h>
#include<share/stdint.h>


#ifndef ASM_FILE


/* ȼ */
typedef int				   bool;
typedef long long		   int64;
typedef unsigned long long uint64;


#define NULL ((void *)0)


#endif


#endif
